@@ -1,4 +1,4 @@
-from .telegram_bot import TelegramBot, UpdateContentType, MessageContentType
+from .bot import Bot, get_bot, UpdateContentType, MessageContentType
 from .dispatcher import (
     Dispatcher,
     Event,
@@ -20,7 +20,7 @@ from .dispatcher import (
 )
 from .state_machine import StateMachine, State, AbstractStateStorage
 from .context import (
-    ContextTelegramBot,
+    ContextBot,
     ContextStateMachine,
     event_context,
     event_handler_context,
@@ -32,12 +32,16 @@ from .utils import (
     NamedSet,
     AbstractCallbackDataBuilder,
     TaskExecutor,
-    Env
+    ThreadPool,
+    Env,
+    get_html_text,
+    get_markdown_text
 )
 
 
 __all__ = [
-    "TelegramBot",
+    "Bot",
+    "get_bot",
     "UpdateContentType",
     "MessageContentType",
     "Dispatcher",
@@ -58,7 +62,7 @@ __all__ = [
     "StateMachine",
     "State",
     "AbstractStateStorage",
-    "ContextTelegramBot",
+    "ContextBot",
     "ContextStateMachine",
     "event_context",
     "event_handler_context",
@@ -68,7 +72,10 @@ __all__ = [
     "NamedSet",
     "AbstractCallbackDataBuilder",
     "TaskExecutor",
+    "ThreadPool",
     "Env",
+    "get_html_text",
+    "get_markdown_text",
     "get_event_chat_id",
     "get_event_user_id"
 ]
@@ -77,8 +84,8 @@ __all__ = [
 def _evaluate_type_annotations() -> None:
     from typing import get_type_hints
 
-    from .telegram_bot.types.types.chat import Chat
-    from .telegram_bot.types.types.message import Message
+    from .bot.types.types.chat import Chat
+    from .bot.types.types.message import Message
 
     classes = (Chat, Message)
     mapping = {i.__name__: i for i in classes}
