@@ -2,14 +2,14 @@ import logging
 from typing import Optional, Union, NoReturn
 from dataclasses import dataclass
 from threading import Thread, Lock
+from requests.exceptions import Timeout as RequestTimeoutError
 import time
 
 import cherrypy
 
-from telebox.telegram_bot.telegram_bot import TelegramBot
-from telebox.telegram_bot.types.types.update import Update
-from telebox.telegram_bot.types.types.message import Message
-from telebox.telegram_bot.errors import UnknownUpdateContentError, UnknownMessageContentError
+from telebox.bot.bot import Bot
+from telebox.bot.types.types.update import Update
+from telebox.bot.types.types.message import Message
 from telebox.dispatcher.typing import Event
 from telebox.dispatcher.utils.media_group import MediaGroup
 from telebox.dispatcher.utils.event_queue import EventQueue
@@ -41,6 +41,7 @@ logger = logging.getLogger(__name__)
 _none_filter = NoneFilter()
 _error_none_filter = ErrorNoneFilter()
 _MEDIA_GROUP_GATHERING_DELAY_SECS = 0.1
+_DROPPED_UNKNOWN_UPDATE_MESSAGE = "Update dropped because it contains an unknown content type: %r."
 
 
 @dataclass
@@ -64,7 +65,7 @@ class Dispatcher:
 
     def __init__(
         self,
-        bot: TelegramBot,
+        bot: Bot,
         *,
         drop_over_limit_events: bool = False,
         default_rate_limit: Optional[RateLimit] = None
@@ -370,11 +371,10 @@ class Dispatcher:
         self,
         threads: int,
         *,
-        timeout_secs: Union[int, float, None] = None,
-        delay_secs: Union[int, float] = 0.2,
-        error_delay_secs: Union[int, float] = 5.0,
+        delay_secs: Union[int, float] = 0,
+        error_delay_secs: Union[int, float] = 5,
         limit: Optional[int] = None,
-        timeout: Optional[int] = None,
+        timeout: Optional[int] = 10,
         allowed_updates: Optional[list[str]] = None
     ) -> None:
         if self._polling_is_used:
@@ -401,12 +401,14 @@ class Dispatcher:
                 # noinspection PyBroadException
                 try:
                     updates = self._bot.get_updates(
-                        timeout_secs=timeout_secs,
+                        timeout_secs=timeout + 1 if timeout else None,
                         offset=offset_update_id,
                         limit=limit,
                         timeout=timeout,
                         allowed_updates=allowed_updates
                     )
+                except RequestTimeoutError:
+                    logger.error("Timeout for requesting updates has expired!")
                 except Exception:
                     logger.exception("An error occurred while receiving updates!")
                     time.sleep(error_delay_secs)
@@ -570,33 +572,23 @@ class Dispatcher:
         self._thread_pool = ThreadPool(
             threads=threads,
             target=self._run_event_processing,
-            args=(self._events,)
+            args=(self._events,),
+            with_barrier=True
         )
         self._thread_pool.start()
 
     def _process_update(self, update: Update) -> None:
         logger.debug("Update received: %r.", update)
+        event = update.content
 
-        try:
-            event, content_type = update.content
-        except UnknownUpdateContentError:
-            logger.debug(
-                "Update skipped because it contains an unknown content type: %r.",
-                update
-            )
+        if event is None:
+            logger.debug(_DROPPED_UNKNOWN_UPDATE_MESSAGE, update)
 
             return
 
-        event_type = EventType(content_type.value)
-
         if isinstance(event, Message):
-            try:
-                event.content  # noqa
-            except UnknownMessageContentError:
-                logger.debug(
-                    "Event skipped because it contains an unknown content type: %r.",
-                    event
-                )
+            if event.content is None:
+                logger.debug(_DROPPED_UNKNOWN_UPDATE_MESSAGE, update)
 
                 return
 
@@ -613,7 +605,7 @@ class Dispatcher:
             logger.debug("Event from over limit chat dropped: %r.", event)
         else:
             logger.debug("Event added to queue: %r.", event)
-            self._events.add_event(event, event_type)
+            self._events.add_event(event, EventType(update.content_type.value))
 
     def _check_over_limit_event(self, event: Event) -> bool:
         return (
@@ -656,7 +648,7 @@ class Dispatcher:
                 event_handler = self._get_event_handler(event.event, event.event_type)
 
                 if event_handler is None:
-                    logger.warning("No handler found for event: %r.", event)
+                    logger.debug("No handler found for event: %r.", event)
                     continue
 
                 event_handler_context.set(event_handler.handler)
