@@ -12,7 +12,8 @@ from .event import (
     ReplyMessageFilter,
     ForwardedMessageFilter,
     ChatTypeFilter,
-    StateFilter,
+    ChatStateFilter,
+    UserStateFilter,
     NonStandardCommandFilter,
     CallbackDataFilter,
     SimpleCallbackDataFilter,
@@ -20,7 +21,9 @@ from .event import (
     CashtagFilter,
     MentionFilter,
     TextMentionFilter,
-    MediaGroupContentTypeFilter
+    MediaGroupContentTypeFilter,
+    NewChatMemberIDFilter,
+    LeftChatMemberIDFilter
 )
 from .error import (
     ErrorNoneFilter,
@@ -45,7 +48,8 @@ __all__ = [
     "ReplyMessageFilter",
     "ForwardedMessageFilter",
     "ChatTypeFilter",
-    "StateFilter",
+    "ChatStateFilter",
+    "UserStateFilter",
     "NonStandardCommandFilter",
     "CallbackDataFilter",
     "SimpleCallbackDataFilter",
@@ -54,5 +58,7 @@ __all__ = [
     "ErrorTypeFilter",
     "ErrorTextFilter",
     "ErrorRegExpTextFilter",
-    "MentionFilter"
+    "MentionFilter",
+    "NewChatMemberIDFilter",
+    "LeftChatMemberIDFilter"
 ]
