@@ -1,7 +1,9 @@
-from typing import Type
+from __future__ import annotations
+from typing import Type, TYPE_CHECKING
 
 from telebox.dispatcher.filters.error_filter import AbstractErrorFilter
-from telebox.dispatcher.typing import Event
+if TYPE_CHECKING:
+    from telebox.dispatcher.typing import Event
 
 
 class ErrorTypeFilter(AbstractErrorFilter):
