@@ -9,7 +9,8 @@ from .user_id import UserIDFilter
 from .reply_message import ReplyMessageFilter
 from .forwarded_message import ForwardedMessageFilter
 from .chat_type import ChatTypeFilter
-from .state import StateFilter
+from .chat_state import ChatStateFilter
+from .user_state import UserStateFilter
 from .non_standard_command import NonStandardCommandFilter
 from .callback_data import CallbackDataFilter
 from .simple_callback_data import SimpleCallbackDataFilter
@@ -18,6 +19,8 @@ from .cashtag import CashtagFilter
 from .mention import MentionFilter
 from .text_mention import TextMentionFilter
 from .media_group_content_type import MediaGroupContentTypeFilter
+from .new_chat_member_id import NewChatMemberIDFilter
+from .left_chat_member_id import LeftChatMemberIDFilter
 
 
 __all__ = [
@@ -32,7 +35,8 @@ __all__ = [
     "ReplyMessageFilter",
     "ForwardedMessageFilter",
     "ChatTypeFilter",
-    "StateFilter",
+    "ChatStateFilter",
+    "UserStateFilter",
     "NonStandardCommandFilter",
     "CallbackDataFilter",
     "SimpleCallbackDataFilter",
@@ -40,5 +44,7 @@ __all__ = [
     "CashtagFilter",
     "MentionFilter",
     "TextMentionFilter",
-    "MediaGroupContentTypeFilter"
+    "MediaGroupContentTypeFilter",
+    "NewChatMemberIDFilter",
+    "LeftChatMemberIDFilter"
 ]
