@@ -3,10 +3,10 @@ from typing import Optional, Union
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
 from telebox.dispatcher.utils.media_group import MediaGroup
-from telebox.telegram_bot.types.types.message import Message
-from telebox.telegram_bot.types.types.callback_query import CallbackQuery
-from telebox.telegram_bot.types.types.chat_member_updated import ChatMemberUpdated
-from telebox.telegram_bot.types.types.chat_join_request import ChatJoinRequest
+from telebox.bot.types.types.message import Message
+from telebox.bot.types.types.callback_query import CallbackQuery
+from telebox.bot.types.types.chat_member_updated import ChatMemberUpdated
+from telebox.bot.types.types.chat_join_request import ChatJoinRequest
 
 
 class ChatIDFilter(AbstractEventFilter):
