@@ -1,7 +1,7 @@
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
-from telebox.telegram_bot.types.types.message import Message
-from telebox.telegram_bot.enums.message_content_type import MessageContentType
+from telebox.bot.types.types.message import Message
+from telebox.bot.enums.message_content_type import MessageContentType
 
 
 class MessageContentTypeFilter(AbstractEventFilter):
