@@ -3,12 +3,12 @@ from typing import Optional, Union
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
 from telebox.dispatcher.utils.media_group import MediaGroup
-from telebox.telegram_bot.types.types.message import Message
+from telebox.bot.types.types.message import Message
 
 
 class NonStandardCommandFilter(AbstractEventFilter):
 
-    def __init__(self, *commands: str, prefix: str, ignore_case: bool = True):
+    def __init__(self, *commands: str, prefix: str = "", ignore_case: bool = True):
         self._commands = set()
 
         for i in commands:
