@@ -3,7 +3,7 @@ from typing import Pattern, Union
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
 from telebox.dispatcher.utils.media_group import MediaGroup
-from telebox.telegram_bot.types.types.message import Message
+from telebox.bot.types.types.message import Message
 
 
 class RegExpTextFilter(AbstractEventFilter):
