@@ -1,6 +1,6 @@
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
-from telebox.telegram_bot.types.types.message import Message
+from telebox.bot.types.types.message import Message
 
 
 class SenderContactFilter(AbstractEventFilter):
