@@ -2,7 +2,7 @@ from typing import Optional
 
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
-from telebox.telegram_bot.types.types.callback_query import CallbackQuery
+from telebox.bot.types.types.callback_query import CallbackQuery
 
 
 class SimpleCallbackDataFilter(AbstractEventFilter):
