@@ -3,15 +3,15 @@ from typing import Optional, Union
 from telebox.dispatcher.filters.event_filter import AbstractEventFilter
 from telebox.dispatcher.enums.event_type import EventType
 from telebox.dispatcher.utils.media_group import MediaGroup
-from telebox.telegram_bot.types.types.message import Message
-from telebox.telegram_bot.types.types.inline_query import InlineQuery
-from telebox.telegram_bot.types.types.chosen_inline_result import ChosenInlineResult
-from telebox.telegram_bot.types.types.callback_query import CallbackQuery
-from telebox.telegram_bot.types.types.shipping_query import ShippingQuery
-from telebox.telegram_bot.types.types.pre_checkout_query import PreCheckoutQuery
-from telebox.telegram_bot.types.types.poll_answer import PollAnswer
-from telebox.telegram_bot.types.types.chat_member_updated import ChatMemberUpdated
-from telebox.telegram_bot.types.types.chat_join_request import ChatJoinRequest
+from telebox.bot.types.types.message import Message
+from telebox.bot.types.types.inline_query import InlineQuery
+from telebox.bot.types.types.chosen_inline_result import ChosenInlineResult
+from telebox.bot.types.types.callback_query import CallbackQuery
+from telebox.bot.types.types.shipping_query import ShippingQuery
+from telebox.bot.types.types.pre_checkout_query import PreCheckoutQuery
+from telebox.bot.types.types.poll_answer import PollAnswer
+from telebox.bot.types.types.chat_member_updated import ChatMemberUpdated
+from telebox.bot.types.types.chat_join_request import ChatJoinRequest
 
 
 class UserIDFilter(AbstractEventFilter):
