@@ -3,7 +3,7 @@ from typing import Optional
 
 from telebox.errors import TeleboxError
 from telebox.state_machine.state import State
-from telebox.dispatcher.handlers.handlers.event import AbstractEventHandler
+from telebox.dispatcher.handlers.event import AbstractEventHandler
 
 
 @dataclass
