@@ -1,5 +1,5 @@
 from __future__ import annotations
-from typing import Optional, Any, TYPE_CHECKING
+from typing import Optional, Union, Any, TYPE_CHECKING
 
 from telebox.state_machine.state import State
 from telebox.state_machine.storages.storage import AbstractStateStorage
@@ -16,6 +16,9 @@ if TYPE_CHECKING:
     from telebox.dispatcher.typing import Event
 
 
+TransitionDict = dict[State, dict[AbstractEventHandler, Union[State, dict[str, State]]]]
+
+
 class StateMachine:
 
     def __init__(self, initial_state: State, storage: AbstractStateStorage):
@@ -51,6 +54,15 @@ class StateMachine:
             if not self.check_state(i):
                 self.add_state(i)
 
+    def add_transitions(self, transitions: TransitionDict) -> None:
+        for source_state in transitions:
+            for handler, destination_item in transitions[source_state].items():
+                if isinstance(destination_item, dict):
+                    for direction, destination_state in destination_item.items():
+                        self.add_transition(source_state, destination_state, handler, direction)
+                else:
+                    self.add_transition(source_state, destination_item, handler)
+
     def check_state(self, state: State) -> bool:
         return self._state_manager.check_state(state)
 
