@@ -11,8 +11,8 @@ Value = Union[str, int, float, bool, list, None]
 
 class JSONCallbackDataBuilder(AbstractCallbackDataBuilder):
 
-    def build(self, key: Key, value: Value = None) -> str:
+    def get_builded_data(self, key: Key, value: Value = None) -> str:
         return ujson.dumps([key, value])
 
-    def parse(self, data: str) -> tuple[Key, Value]:
+    def get_parsed_data(self, data: str) -> tuple[Key, Value]:
         return tuple(ujson.loads(data))
